@@ -1,6 +1,6 @@
 import stripe
 import pandas as pd
-from . utils import utils
+from . import utils
 
 
 class StripeAdapter:
